@@ -13,11 +13,6 @@ use MegaDistro::Config qw(:default $DEVNULL);
 use MegaDistro::RpmMaker::Config qw(:default :build);
 use MegaDistro::RpmMaker::SpecFile qw(make_specfile);
 
-use File::Spec::Functions qw(:ALL);
-use File::Find;
-use Archive::Tar;
-
-no warnings 'File::Find';
 
 sub have_rpm {
 	`rpmbuild --help > /dev/null 2>&1`;
@@ -61,11 +56,8 @@ sub tarball_rpm {
 	#create src tarball
 	my $TARBALL = $metadata{'name'} . '-' . $metadata{'version'} . '.tar.gz';
 
-	my @files;
-	find(sub{push@files,abs2rel($File::Find::name,$Conf{'builddir'})},$Conf{'builddir'});
-	shift @files if !$files[0];
-	chdir $Conf{'builddir'};
-	my $tar = Archive::Tar->create_archive(catdir($buildtree{'SOURCES'},$TARBALL),9,@files);
+	
+	system( "cd $Conf{'builddir'}; tar zcvf $buildtree{'SOURCES'}/$TARBALL * > $DEVNULL; cd $Conf{'rootdir'}" ); #safety
 
 #	#check for tarball and copy to SOURCES directory
 #	if ( -s "$Conf{'rootdir'}/$TARBALL" ) {
@@ -102,10 +94,10 @@ sub build_rpm {
 	#check for specfile, and package.
 	if ( -e "$buildtree{'specfile'}" ) {
 		if ( !$args{'verbose'} ) {
-			system( "rpmbuild --rcfile $buildtree{'drcfile'}:$buildtree{'rcfile'} -bb $addopts $buildtree{'specfile'} > $DEVNULL" );
+			system( "rpmbuild --rcfile $buildtree{'rcfile'} -bb $addopts $buildtree{'specfile'} > $DEVNULL" );
 		}
 		else {
-			system( "rpmbuild --rcfile $buildtree{'drcfile'}:$buildtree{'rcfile'} -bb $addopts $buildtree{'specfile'}" );
+			system( "rpmbuild --rcfile $buildtree{'rcfile'} -bb $addopts $buildtree{'specfile'}" );
 		}
 	}
 	else {
