@@ -13,9 +13,6 @@ $EXPORT_TAGS{'build'} = \@EXPORT_OK;
 	
 use lib '../MegaDistro';
 
-use File::Path;
-use File::Spec::Functions qw(:ALL);
-
 use MegaDistro;
 use MegaDistro::Config;
 
@@ -32,13 +29,13 @@ our %metadata = (
 		  'summary'	=>	'A pre-compiled set of perl modules',
 		 
 		  # the package Name
-		  'name'	=>	'megadistro',	
+		  'name'		=>	'megadistro',	
 		 
 		  # the package Version
 		  'version'	=>	$MegaDistro::VERSION,		
 		 
 		  # the package Release number
-		  'release'	=>	'5',
+		  'release'	=>	'1',		
 		 
 		  # the package License
 		  'license'	=>	'GPL',		
@@ -47,10 +44,10 @@ our %metadata = (
 		  'group'	=>	'Development/Libraries',
 		 
 		  # the package Source location
-		  'source'	=>	'http://search.cpan.org/CPAN/authors/id/D/DB/DBUCHMAN/megadistro-0.02.tar.gz',
+		  'source'	=>	'https://svn.perl.org/projects/perlplus/trunk/megadistro-0.01.tar.gz',
 		 
-		  # the package URL
-		  'url'		=>	'http://search.cpan.org/~dbuchman/MegaDistro-0.02/',
+#		  # the package URL
+#		  'url'		=>	'http://www.mysite.com/megadistro/megadistro.html',
 		 
 		  # the package Requires (depends)
 		  'requires'	  =>	'perl >= 5.6.1',
@@ -116,37 +113,34 @@ $stanza{'install'} = [
 sub _init_globals { #hack a la megadistro
 
 	# rpmbuild-tree prefix
-	$buildtree{'prefixdir'}  = catdir($Conf{'rootdir'}, 'rpmbuild');
+	$buildtree{'prefixdir'} = $Conf{'rootdir'} . '/' . 'rpmbuild';
 
 	# SOURCES directory
-	$buildtree{'SOURCES'}    = catdir($buildtree{'prefixdir'}, 'SOURCES');
+	$buildtree{'SOURCES'}   = $buildtree{'prefixdir'} . '/' . "SOURCES";
 
 	# BUILD directory
-	$buildtree{'BUILD'}      = catdir($buildtree{'prefixdir'}, 'BUILD');
+	$buildtree{'BUILD'}     = $buildtree{'prefixdir'} . '/' . "BUILD";
 
 	# RPMS directory
-	$buildtree{'RPMS'}       = catdir($buildtree{'prefixdir'}, 'RPMS');
+	$buildtree{'RPMS'}      = $buildtree{'prefixdir'} . '/' . "RPMS";
 
 	# SRPMS directory
-	$buildtree{'SRPMS'}      = catdir($buildtree{'prefixdir'}, 'SRPMS');
+	$buildtree{'SRPMS'}     = $buildtree{'prefixdir'} . '/' . "SRPMS";
 	
 	# SPECS directory
-	$buildtree{'SPECS'}      = catdir($buildtree{'prefixdir'}, 'SPECS');
+	$buildtree{'SPECS'}     = $buildtree{'prefixdir'} . '/' . "SPECS";
 
 	# the name of the rpm spec file
-	$buildtree{'specfile'}   = catdir($buildtree{'SPECS'}, 'megadistro.spec');
+	$buildtree{'specfile'}  = $buildtree{'SPECS'}     . '/' . 'megadistro.spec';
 	
 	# the name of the rpm rc file
-	$buildtree{'rcfile'}     = $buildtree{'prefixdir'} . '/' . '.rpmrc';
-
-	# the name of the default rcfile
-	$buildtree{'drcfile'}    = '/usr/lib/rpm/rpmrc';
+	$buildtree{'rcfile'}    = $buildtree{'prefixdir'} . '/' . '.rpmrc';
 	
 	# the name of the rpm macros file
 	$buildtree{'macrosfile'} = $buildtree{'prefixdir'} . '/' . '.rpmmacros';
 	
 	# the package BuildArch hardware platform
-	$metadata{'buildarch'}   = `rpm --eval %{_build_arch} 2>&1`; chomp $metadata{'buildarch'};
+	$metadata{'buildarch'}  = `rpm --eval %{_build_arch} 2>&1`; chomp $metadata{'buildarch'};
 }
 
 #
@@ -157,11 +151,11 @@ sub build_pre {
 		print 'MegaDistro::SpecFile::Config : Executing sub-routine: build_pre' . "\n";
 	}
 	
-	mkpath $buildtree{'SOURCES'} if ! -d $buildtree{'SOURCES'};
-	mkpath $buildtree{'BUILD'}   if ! -d $buildtree{'BUILD'};
-	mkpath $buildtree{'RPMS'}    if ! -d $buildtree{'RPMS'};
-	mkpath $buildtree{'SRPMS'}   if ! -d $buildtree{'SRPMS'};
-	mkpath $buildtree{'SPECS'}   if ! -d $buildtree{'SPECS'};
+	system( "mkdir -p $buildtree{'SOURCES'}" ) if ! -d $buildtree{'SOURCES'};
+	system( "mkdir -p $buildtree{'BUILD'}" )   if ! -d $buildtree{'BUILD'};
+	system( "mkdir -p $buildtree{'RPMS'}" )    if ! -d $buildtree{'RPMS'};
+	system( "mkdir -p $buildtree{'SRPMS'}" )   if ! -d $buildtree{'SRPMS'};
+	system( "mkdir -p $buildtree{'SPECS'}" )   if ! -d $buildtree{'SPECS'};
 }
 
 1;
